# CHANGELOG

## 0.2.1

| Version | 0.2.1      |
| ------- | ---------- |
| Date    | 2021-11-05 |

- New Features:
  - update to PyYAML 6.0

## 0.2

- Date: 2021-09-08

- new api
- update to Jinja2 3.0

## 0.2a1

Many APIs changed in `v0.2`

## v0.1

An early version, maybe not stable enough.
